@@ -21,8 +21,8 @@ class AccordionEntry(EntryBlock):
         classic = {
             'type': 'classic',
             'value': {
-                'head': {'value': self.mocker.p},
-                'content': {'value': self.mocker.p},
+                'head': {'value': self.p},
+                'content': {'value': self.p},
             }
         }
 
